@@ -318,108 +318,7 @@ suite('<os-settings-bluetooth-device-detail-subpage>', () => {
     assertTrue(!!getTrueWirelessImages());
   });
 
-  test(
-      'Show change settings row, and navigate to subpages' +
-      'w/ no per-device settings',
-      async () => {
-        loadTimeData.overrideValues({
-          enableInputDeviceSettingsSplit: false,
-        });
-
-        init();
-        bluetoothConfig.setBluetoothEnabledState(/*enabled=*/ true);
-
-        const device1 = createDefaultBluetoothDevice(
-            /*id=*/ '12//345&6789',
-            /*publicName=*/ 'BeatsX',
-            /*connectionState=*/
-            DeviceConnectionState.kConnected,
-            /*opt_nickname=*/ 'device1',
-            /*opt_audioCapability=*/
-            AudioOutputCapability.kCapableOfAudioOutput,
-            /*opt_deviceType=*/ DeviceType.kMouse);
-
-        bluetoothConfig.appendToPairedDeviceList([device1]);
-        await flushTasks();
-
-        navigateToDeviceDetailPage('12//345&6789');
-
-        device1.deviceProperties.connectionState =
-            DeviceConnectionState.kNotConnected;
-        bluetoothConfig.updatePairedDevice(device1);
-        await flushTasks();
-        assertNull(getChangeMouseSettings());
-
-        device1.deviceProperties.connectionState =
-            DeviceConnectionState.kConnected;
-        bluetoothConfig.updatePairedDevice(device1);
-        await flushTasks();
-        assertTrue(!!getChangeMouseSettings());
-
-        getChangeMouseSettings()!.click();
-        await flushTasks();
-
-        assertEquals(routes.POINTERS, Router.getInstance().currentRoute);
-
-        // Navigate back to the detail page.
-        assertNotEquals(
-            bluetoothDeviceDetailPage.shadowRoot!.activeElement,
-            getChangeMouseSettings());
-        let windowPopstatePromise = eventToPromise('popstate', window);
-        Router.getInstance().navigateToPreviousRoute();
-        await windowPopstatePromise;
-        await waitAfterNextRender(bluetoothDeviceDetailPage);
-
-        assertTrue(bluetoothDeviceDetailPage.getIsDeviceConnectedForTest());
-        // Check that |#changeMouseSettings| has been focused.
-        assertEquals(
-            bluetoothDeviceDetailPage.shadowRoot!.activeElement,
-            getChangeMouseSettings());
-
-        device1.deviceProperties.deviceType = DeviceType.kKeyboard;
-        bluetoothConfig.updatePairedDevice(device1);
-
-        await flushTasks();
-        assertNull(getChangeMouseSettings());
-        assertTrue(!!getChangeKeyboardSettings());
-
-        device1.deviceProperties.connectionState =
-            DeviceConnectionState.kNotConnected;
-        bluetoothConfig.updatePairedDevice(device1);
-        await flushTasks();
-        assertNull(getChangeKeyboardSettings());
-
-        device1.deviceProperties.connectionState =
-            DeviceConnectionState.kConnected;
-        bluetoothConfig.updatePairedDevice(device1);
-        await flushTasks();
-        assertTrue(!!getChangeKeyboardSettings());
-
-        getChangeKeyboardSettings()!.click();
-        await flushTasks();
-
-        assertEquals(routes.KEYBOARD, Router.getInstance().currentRoute);
-
-        // Navigate back to the detail page.
-        assertNotEquals(
-            bluetoothDeviceDetailPage.shadowRoot!.activeElement,
-            getChangeKeyboardSettings());
-        windowPopstatePromise = eventToPromise('popstate', window);
-        Router.getInstance().navigateToPreviousRoute();
-        await windowPopstatePromise;
-        await waitAfterNextRender(bluetoothDeviceDetailPage);
-
-        // This is needed or other tests will fail.
-        // TODO(crbug.com/390256207): Figure out how to remove this.
-        getChangeKeyboardSettings()!.click();
-        await flushTasks();
-      });
-
   test('Show change settings row, and navigate to subpages', async () => {
-    loadTimeData.overrideValues({
-      enableInputDeviceSettingsSplit: true,
-    });
-
     init();
     bluetoothConfig.setBluetoothEnabledState(/*enabled=*/ true);
 
