@@ -148,8 +148,11 @@ export interface PageElementTypes {
   viewChangedCurrentView: HTMLSelectElement;
   viewChangedAutomaticallyAccept: HTMLInputElement;
   mqlsClientIdBtn: HTMLButtonElement;
+  additionalContextResult: HTMLTextAreaElement;
+  additionalContextImages: HTMLDivElement;
   multiTabFetchScreenshot: HTMLInputElement;
   conversationIdInput: HTMLInputElement;
+  conversationTitleInput: HTMLInputElement;
   switchConversationBtn: HTMLButtonElement;
   registerConversationBtn: HTMLButtonElement;
   conversationId: HTMLInputElement;
