@@ -19,6 +19,7 @@ export class TestLensSidePanelPageHandler extends TestBrowserProxy implements
       'onScrollToMessage',
       'requestSendFeedback',
       'onAimMessage',
+      'onImageQueryWithEmptyText',
     ]);
   }
 
@@ -46,6 +47,10 @@ export class TestLensSidePanelPageHandler extends TestBrowserProxy implements
   requestSendFeedback() {
     this.methodCalled('requestSendFeedback');
   }
+
+  onImageQueryWithEmptyText() {
+    this.methodCalled('onImageQueryWithEmptyText');
+  }
 }
 
 /**
