@@ -182,88 +182,6 @@ suite('RestrictedEnabled', function() {
   });
 });
 
-suite('FledgeSubpage', function() {
-  let page: SettingsPrivacySandboxFledgeSubpageElement;
-  let testPrivacySandboxBrowserProxy: TestPrivacySandboxBrowserProxy;
-  let settingsPrefs: SettingsPrefsElement;
-
-  suiteSetup(function() {
-    loadTimeData.overrideValues({
-      isPrivacySandboxRestricted: false,
-      isPrivacySandboxAdsApiUxEnhancementsEnabled: false,
-    });
-    settingsPrefs = document.createElement('settings-prefs');
-    return CrSettingsPrefs.initialized;
-  });
-
-  setup(async function() {
-    testPrivacySandboxBrowserProxy = new TestPrivacySandboxBrowserProxy();
-    testPrivacySandboxBrowserProxy.setFledgeState({
-      joiningSites: ['test-site-one.com'],
-      blockedSites: ['test-site-two.com'],
-    });
-    PrivacySandboxBrowserProxyImpl.setInstance(testPrivacySandboxBrowserProxy);
-    document.body.innerHTML = window.trustedTypes!.emptyHTML;
-    document.body.appendChild(settingsPrefs);
-    page = document.createElement('settings-privacy-sandbox-fledge-subpage');
-    page.prefs = settingsPrefs.prefs!;
-    document.body.appendChild(page);
-    await testPrivacySandboxBrowserProxy.whenCalled('getFledgeState');
-    return flushTasks();
-  });
-
-  teardown(function() {
-    Router.getInstance().resetRouteForTesting();
-  });
-
-  test('secondDescription', function() {
-    const secondDescription =
-        page.shadowRoot!.querySelector<HTMLElement>('#secondDescription');
-    assert(secondDescription);
-    assertEquals(
-        secondDescription?.innerText, page.i18n('fledgePageExplanation'));
-  });
-
-  test('footerLinks', function() {
-    assertTrue(isChildVisible(page, '#footer'));
-    const links =
-        page.shadowRoot!.querySelectorAll<HTMLAnchorElement>('#footer a[href]');
-    assertEquals(links.length, 3, 'footer should contains three links');
-    links.forEach(
-        link => assertEquals(
-            link.getAttribute('aria-description'),
-            loadTimeData.getString('opensInNewTab'),
-            'the link should indicate that it will be opened in a new tab'));
-    const hrefs = Array.from<HTMLAnchorElement>(links).map(link => link.href);
-    const expectedLinks = [
-      'chrome://settings/adPrivacy/interests',
-      'chrome://settings/cookies',
-      'https://support.google.com/chrome?p=ad_privacy',
-    ];
-    assertDeepEquals(hrefs, expectedLinks);
-  });
-
-  test('siteSuggestedAdsContentV2NotShown', async function() {
-    assertTrue(isVisible(page.shadowRoot!.querySelector('#fledgeToggle')));
-    assertFalse(
-        isVisible(page.shadowRoot!.querySelector('#siteSuggestedAdsToggleV2')));
-    assertTrue(isVisible(page.shadowRoot!.querySelector('#secondDescription')));
-    assertFalse(
-        isVisible(page.shadowRoot!.querySelector('#secondDescriptionV2')));
-    assertTrue(isVisible(page.shadowRoot!.querySelector('#footer')));
-    assertFalse(isVisible(page.shadowRoot!.querySelector('#footerV2')));
-    assertFalse(isVisible(page.shadowRoot!.querySelector('#disclaimer')));
-    const learnMoreLink =
-        page.shadowRoot!.querySelector<HTMLElement>('#learnMoreLink');
-    assertTrue(!!learnMoreLink);
-    assertTrue(isVisible(learnMoreLink));
-    assertFalse(isVisible(page.shadowRoot!.querySelector('#learnMoreLinkV2')));
-    learnMoreLink.click();
-    await flushTasks();
-    assertTrue(isVisible(page.shadowRoot!.querySelector('#body')));
-    assertFalse(isVisible(page.shadowRoot!.querySelector('#bodyV2')));
-  });
-});
 
 suite('SiteSuggestedAdsSubpageAdsApiUxEnhancement', function() {
   let page: SettingsPrivacySandboxFledgeSubpageElement;
@@ -274,7 +192,6 @@ suite('SiteSuggestedAdsSubpageAdsApiUxEnhancement', function() {
   suiteSetup(function() {
     loadTimeData.overrideValues({
       isPrivacySandboxRestricted: false,
-      isPrivacySandboxAdsApiUxEnhancementsEnabled: true,
     });
     settingsPrefs = document.createElement('settings-prefs');
     return CrSettingsPrefs.initialized;
@@ -452,8 +369,6 @@ suite('TopicsSubpage', function() {
       '#manageTopicsSection',
     ];
     idsToBeHidden.forEach(id => assertFalse(isChildVisible(page, id)));
-    // footer should be visible if pref is on or not.
-    assertTrue(isChildVisible(page, '#footer'));
     assertEquals(
         0, testPrivacySandboxBrowserProxy.getCallCount('topicsToggleChanged'));
 
@@ -498,7 +413,6 @@ suite('TopicsSubpage', function() {
       '#blockedTopicsDescription',
       '#blockedTopicsList',
       '#manageTopicsSection',
-      '#footer',
     ];
     idsToBeShown.forEach(id => assertTrue(isChildVisible(page, id)));
   });
@@ -535,7 +449,6 @@ suite('TopicsSubpage', function() {
       '#blockedTopicsDescription',
       '#blockedTopicsList',
       '#manageTopicsSection',
-      '#footer',
     ];
     idsToBeShown.forEach(id => assertTrue(isChildVisible(page, id)));
 
@@ -940,25 +853,6 @@ suite('TopicsSubpage', function() {
     assertFalse(isChildVisible(page, '#currentTopicsSection'));
   });
 
-  test('footerLinks', function() {
-    assertTrue(isChildVisible(page, '#footer'));
-    const links =
-        page.shadowRoot!.querySelectorAll<HTMLAnchorElement>('#footer a[href]');
-    assertEquals(links.length, 3, 'footer should contains three links');
-    links.forEach(
-        link => assertEquals(
-            link.getAttribute('aria-description'),
-            loadTimeData.getString('opensInNewTab'),
-            'the link should indicate that it will be opened in a new tab'));
-    const hrefs = Array.from<HTMLAnchorElement>(links).map(link => link.href);
-    const expectedLinks = [
-      'chrome://settings/adPrivacy/sites',
-      'chrome://settings/cookies',
-      'https://support.google.com/chrome?p=ad_privacy',
-    ];
-    assertDeepEquals(hrefs, expectedLinks);
-  });
-
   test('manageTopicsRow', function() {
     const manageTopicsRow = page.shadowRoot!.querySelector<CrLinkRowElement>(
         '#privacySandboxManageTopicsLinkRow');
@@ -994,70 +888,6 @@ suite('TopicsSubpage', function() {
   });
 });
 
-suite('TopicsSubpageAdsApiUxEnhancementsDisabled', function() {
-  let page: SettingsPrivacySandboxTopicsSubpageElement;
-  let testPrivacySandboxBrowserProxy: TestPrivacySandboxBrowserProxy;
-  let settingsPrefs: SettingsPrefsElement;
-  let metricsBrowserProxy: TestMetricsBrowserProxy;
-
-  suiteSetup(function() {
-    loadTimeData.overrideValues({
-      isPrivacySandboxRestricted: false,
-      isPrivacySandboxAdsApiUxEnhancementsEnabled: false,
-    });
-    settingsPrefs = document.createElement('settings-prefs');
-    return CrSettingsPrefs.initialized;
-  });
-
-  setup(async function() {
-    testPrivacySandboxBrowserProxy = new TestPrivacySandboxBrowserProxy();
-    PrivacySandboxBrowserProxyImpl.setInstance(testPrivacySandboxBrowserProxy);
-    metricsBrowserProxy = new TestMetricsBrowserProxy();
-    MetricsBrowserProxyImpl.setInstance(metricsBrowserProxy);
-
-    document.body.innerHTML = window.trustedTypes!.emptyHTML;
-    document.body.appendChild(settingsPrefs);
-    page = document.createElement('settings-privacy-sandbox-topics-subpage');
-    page.prefs = settingsPrefs.prefs!;
-    page.set('prefs.privacy_sandbox.m1.topics_enabled', {value: true});
-    Router.getInstance().navigateTo(routes.PRIVACY_SANDBOX_TOPICS);
-    document.body.appendChild(page);
-    await testPrivacySandboxBrowserProxy.whenCalled('getTopicsState');
-    return flushTasks();
-  });
-
-  teardown(function() {
-    Router.getInstance().resetRouteForTesting();
-  });
-
-  test('footerLinksV2NotShown', function() {
-    assertTrue(isVisible(page.shadowRoot!.querySelector('#footer')));
-    const links =
-        page.shadowRoot!.querySelectorAll<HTMLAnchorElement>('#footer a[href]');
-    assertEquals(links.length, 3, 'footer should contains three links');
-    links.forEach(
-        link => assertEquals(
-            link.getAttribute('aria-description'),
-            loadTimeData.getString('opensInNewTab'),
-            'the link should indicate that it will be opened in a new tab'));
-    const hrefs = Array.from<HTMLAnchorElement>(links).map(link => link.href);
-    const expectedLinks = [
-      'chrome://settings/adPrivacy/sites',
-      'chrome://settings/cookies',
-      'https://support.google.com/chrome?p=ad_privacy',
-    ];
-    assertDeepEquals(hrefs, expectedLinks);
-  });
-
-  test('TopicsPageContentV2NotShown', function() {
-    assertTrue(isVisible(page.shadowRoot!.querySelector('#footer')));
-    assertFalse(isVisible(page.shadowRoot!.querySelector('#footerV2')));
-    const footerDisclaimer =
-        page.shadowRoot!.querySelector('#footerDisclaimer');
-    assertFalse(isVisible(footerDisclaimer));
-  });
-});
-
 suite('TopicsSubpageAdsApiUxEnhancements', function() {
   let page: SettingsPrivacySandboxTopicsSubpageElement;
   let testPrivacySandboxBrowserProxy: TestPrivacySandboxBrowserProxy;
@@ -1067,7 +897,6 @@ suite('TopicsSubpageAdsApiUxEnhancements', function() {
   suiteSetup(function() {
     loadTimeData.overrideValues({
       isPrivacySandboxRestricted: false,
-      isPrivacySandboxAdsApiUxEnhancementsEnabled: true,
     });
     settingsPrefs = document.createElement('settings-prefs');
     return CrSettingsPrefs.initialized;
@@ -2046,40 +1875,6 @@ suite('AdMeasurementSubpage', function() {
   });
 });
 
-suite('AdMeasurementSubpageAdsApiUxEnhancementsDisabled', function() {
-  let page: SettingsPrivacySandboxAdMeasurementSubpageElement;
-  let settingsPrefs: SettingsPrefsElement;
-
-  suiteSetup(function() {
-    loadTimeData.overrideValues({
-      isPrivacySandboxRestricted: false,
-      isPrivacySandboxAdsApiUxEnhancementsEnabled: false,
-    });
-    settingsPrefs = document.createElement('settings-prefs');
-    return CrSettingsPrefs.initialized;
-  });
-
-  setup(function() {
-    document.body.innerHTML = window.trustedTypes!.emptyHTML;
-    document.body.appendChild(settingsPrefs);
-    page = document.createElement(
-        'settings-privacy-sandbox-ad-measurement-subpage');
-    page.prefs = settingsPrefs.prefs!;
-    Router.getInstance().navigateTo(routes.PRIVACY_SANDBOX_AD_MEASUREMENT);
-    document.body.appendChild(page);
-    return flushTasks();
-  });
-
-  teardown(function() {
-    Router.getInstance().resetRouteForTesting();
-  });
-
-  test('contentV2NotShown', function() {
-    const disclaimer = page.shadowRoot!.querySelector('#disclaimer');
-    assertFalse(isVisible(disclaimer));
-  });
-});
-
 suite('AdMeasurementSubpageAdsApiUxEnhancements', function() {
   let page: SettingsPrivacySandboxAdMeasurementSubpageElement;
   let settingsPrefs: SettingsPrefsElement;
@@ -2088,7 +1883,6 @@ suite('AdMeasurementSubpageAdsApiUxEnhancements', function() {
   suiteSetup(function() {
     loadTimeData.overrideValues({
       isPrivacySandboxRestricted: false,
-      isPrivacySandboxAdsApiUxEnhancementsEnabled: true,
     });
     settingsPrefs = document.createElement('settings-prefs');
     return CrSettingsPrefs.initialized;
@@ -2128,8 +1922,7 @@ suite('AdMeasurementSubpageAdsApiUxEnhancements', function() {
   });
 });
 
-// PrivacySandboxAdsTopicsContentParity and PrivacySandboxAdsApiUxEnhancements
-// are enabled.
+// PrivacySandboxAdsTopicsContentParity is enabled.
 suite('TopicsSubpageAdTopicsContentParity', function() {
   let page: SettingsPrivacySandboxTopicsSubpageElement;
   let testPrivacySandboxBrowserProxy: TestPrivacySandboxBrowserProxy;
@@ -2139,7 +1932,6 @@ suite('TopicsSubpageAdTopicsContentParity', function() {
   suiteSetup(function() {
     loadTimeData.overrideValues({
       isPrivacySandboxRestricted: false,
-      isPrivacySandboxAdsApiUxEnhancementsEnabled: true,
     });
     settingsPrefs = document.createElement('settings-prefs');
     return CrSettingsPrefs.initialized;
@@ -2197,8 +1989,7 @@ suite('TopicsSubpageAdTopicsContentParity', function() {
   });
 });
 
-// PrivacySandboxAdsTopicsContentParity is disabled and
-// PrivacySandboxAdsApiUxEnhancements is enabled.
+// PrivacySandboxAdsTopicsContentParity is disabled
 suite('TopicsSubpageAdTopicsContentParityDisabled', function() {
   let page: SettingsPrivacySandboxTopicsSubpageElement;
   let testPrivacySandboxBrowserProxy: TestPrivacySandboxBrowserProxy;
@@ -2208,7 +1999,6 @@ suite('TopicsSubpageAdTopicsContentParityDisabled', function() {
   suiteSetup(function() {
     loadTimeData.overrideValues({
       isPrivacySandboxRestricted: false,
-      isPrivacySandboxAdsApiUxEnhancementsEnabled: true,
     });
     settingsPrefs = document.createElement('settings-prefs');
     return CrSettingsPrefs.initialized;
@@ -2265,67 +2055,3 @@ suite('TopicsSubpageAdTopicsContentParityDisabled', function() {
         isVisible(page.shadowRoot!.querySelector('#currentTopicsDescription')));
   });
 });
-
-// PrivacySandboxAdsTopicsContentParity is enabled and
-// PrivacySandboxAdsApiUxEnhancements is disabled.
-suite(
-    'TopicsSubpageAdTopicsContentParityAdsApiUxEnhancementDisabled',
-    function() {
-      let page: SettingsPrivacySandboxTopicsSubpageElement;
-      let testPrivacySandboxBrowserProxy: TestPrivacySandboxBrowserProxy;
-      let settingsPrefs: SettingsPrefsElement;
-      let metricsBrowserProxy: TestMetricsBrowserProxy;
-
-      suiteSetup(function() {
-        loadTimeData.overrideValues({
-          isPrivacySandboxRestricted: false,
-          isPrivacySandboxAdsApiUxEnhancementsEnabled: false,
-        });
-        settingsPrefs = document.createElement('settings-prefs');
-        return CrSettingsPrefs.initialized;
-      });
-
-      setup(async function() {
-        testPrivacySandboxBrowserProxy = new TestPrivacySandboxBrowserProxy();
-        testPrivacySandboxBrowserProxy
-            .setShouldShowPrivacySandboxAdTopicsContentParity(true);
-        PrivacySandboxBrowserProxyImpl.setInstance(
-            testPrivacySandboxBrowserProxy);
-        metricsBrowserProxy = new TestMetricsBrowserProxy();
-        MetricsBrowserProxyImpl.setInstance(metricsBrowserProxy);
-
-        document.body.innerHTML = window.trustedTypes!.emptyHTML;
-        document.body.appendChild(settingsPrefs);
-        page =
-            document.createElement('settings-privacy-sandbox-topics-subpage');
-        page.prefs = settingsPrefs.prefs!;
-        page.set('prefs.privacy_sandbox.m1.topics_enabled', {value: true});
-        Router.getInstance().navigateTo(routes.PRIVACY_SANDBOX_TOPICS);
-        document.body.appendChild(page);
-        await testPrivacySandboxBrowserProxy.whenCalled('getTopicsState');
-        return flushTasks();
-      });
-
-      teardown(function() {
-        Router.getInstance().resetRouteForTesting();
-      });
-
-      test('AdsApiUxEnhancementsDisabled', function() {
-        const topicsToggle =
-            page.shadowRoot!.querySelector<SettingsToggleButtonElement>(
-                '#topicsToggle');
-        assert(topicsToggle);
-        assertTrue(isVisible(topicsToggle));
-        assertEquals(
-            loadTimeData.getString('adTopicsPageToggleSubLabel'),
-            topicsToggle.subLabel);
-        assertTrue(isVisible(
-            page.shadowRoot!.querySelector('#currentTopicsDescriptionV2')));
-        assertFalse(isVisible(
-            page.shadowRoot!.querySelector('#currentTopicsDescription')));
-        assertFalse(
-            isVisible(page.shadowRoot!.querySelector('#footerDisclaimerV2')));
-        assertFalse(
-            isVisible(page.shadowRoot!.querySelector('#footerDisclaimer')));
-      });
-    });
