@@ -7,8 +7,8 @@ import 'chrome://settings/lazy_load.js';
 
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import type {SettingsOmniboxExtensionEntryElement, SettingsSearchEngineEntryElement} from 'chrome://settings/lazy_load.js';
-import type {SearchEngine} from 'chrome://settings/settings.js';
-import {ExtensionControlBrowserProxyImpl, SearchEnginesBrowserProxyImpl, ChoiceMadeLocation} from 'chrome://settings/settings.js';
+import type { SearchEngine, CrActionMenuElement } from 'chrome://settings/settings.js';
+import { ExtensionControlBrowserProxyImpl, SearchEnginesBrowserProxyImpl, ChoiceMadeLocation } from 'chrome://settings/settings.js';
 import {assertEquals, assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import { eventToPromise, isVisible } from 'chrome://webui-test/test_util.js';
 
@@ -16,6 +16,49 @@ import {TestExtensionControlBrowserProxy} from './test_extension_control_browser
 import {createSampleOmniboxExtension, createSampleSearchEngine, TestSearchEnginesBrowserProxy} from './test_search_engines_browser_proxy.js';
 // clang-format on
 
+/**
+ * Opens and returns the action menu for a SettingsSearchEngineEntryElement.
+ */
+function openActionMenu(entry: SettingsSearchEngineEntryElement):
+    CrActionMenuElement {
+  const menuButton = entry.shadowRoot!.querySelector<HTMLElement>(
+      'cr-icon-button.icon-more-vert');
+  assertTrue(!!menuButton);
+  menuButton.click();
+  const menu = entry.shadowRoot!.querySelector('cr-action-menu');
+  assertTrue(!!menu);
+  assertTrue(menu.open);
+  return menu;
+}
+
+/**
+ * Checks that the given button is hidden.
+ */
+function assertButtonHidden(
+    entry: SettingsSearchEngineEntryElement, buttonId: string,
+    searchEngine?: SearchEngine) {
+  if (searchEngine) {
+    entry.engine = searchEngine;
+  }
+  const button = entry.shadowRoot!.querySelector<HTMLButtonElement>(buttonId);
+  assertTrue(!!button);
+  assertTrue(button.hidden);
+}
+
+/**
+ * Returns whether the given button is disabled.
+ */
+function isButtonDisabled(
+    entry: SettingsSearchEngineEntryElement, buttonId: string,
+    searchEngine?: SearchEngine): boolean {
+  if (searchEngine) {
+    entry.engine = searchEngine;
+  }
+  const button = entry.shadowRoot!.querySelector<HTMLButtonElement>(buttonId);
+  assertTrue(!!button);
+  return button.disabled;
+}
+
 suite('SearchEngineEntryTest', function() {
   let entry: SettingsSearchEngineEntryElement;
   let browserProxy: TestSearchEnginesBrowserProxy;
@@ -24,9 +67,9 @@ suite('SearchEngineEntryTest', function() {
       {canBeDefault: true, canBeEdited: true, canBeRemoved: true});
 
   setup(function() {
+    document.body.innerHTML = window.trustedTypes!.emptyHTML;
     browserProxy = new TestSearchEnginesBrowserProxy();
     SearchEnginesBrowserProxyImpl.setInstance(browserProxy);
-    document.body.innerHTML = window.trustedTypes!.emptyHTML;
     entry = document.createElement('settings-search-engine-entry');
     entry.engine = searchEngine;
     document.body.appendChild(entry);
@@ -35,7 +78,6 @@ suite('SearchEngineEntryTest', function() {
   // Test that the <search-engine-entry> is populated according to its
   // underlying SearchEngine model.
   test('Initialization', function() {
-    flush();
     assertEquals(
         searchEngine.displayName,
         entry.shadowRoot!.querySelector('#name-column')!.textContent!.trim());
@@ -49,8 +91,6 @@ suite('SearchEngineEntryTest', function() {
 
   // Tests that columns are hidden and shown appropriately.
   test('ColumnVisibility', function() {
-    flush();
-
     // Test shortcut column visibility.
     entry.showShortcut = true;
     assertFalse(
@@ -69,23 +109,11 @@ suite('SearchEngineEntryTest', function() {
         entry.shadowRoot!.querySelector<HTMLElement>('#url-column')!.hidden);
   });
 
-  // Open and return the action menu
-  function openActionMenu() {
-    const menuButton = entry.shadowRoot!.querySelector<HTMLElement>(
-        'cr-icon-button.icon-more-vert');
-    assertTrue(!!menuButton);
-    menuButton.click();
-    const menu = entry.shadowRoot!.querySelector('cr-action-menu')!;
-    assertTrue(menu.open);
-    return menu;
-  }
-
   test('Remove_Enabled', async function() {
-    const menu = openActionMenu();
+    const menu = openActionMenu(entry);
 
     const deleteButton = entry.$.delete;
-    assertTrue(!!deleteButton);
-    assertFalse(deleteButton.hidden);
+    assertTrue(isVisible(deleteButton));
     deleteButton.click();
     const modelIndex = await browserProxy.whenCalled('removeSearchEngine');
     assertFalse(menu.open);
@@ -93,7 +121,7 @@ suite('SearchEngineEntryTest', function() {
   });
 
   test('MakeDefault_Enabled', async function() {
-    const menu = openActionMenu();
+    const menu = openActionMenu(entry);
 
     const makeDefaultButton = entry.$.makeDefault;
     assertTrue(!!makeDefaultButton);
@@ -107,13 +135,10 @@ suite('SearchEngineEntryTest', function() {
 
   // Test that clicking the "edit" menu item fires an edit event.
   test('Edit_Enabled', function() {
-    flush();
-
     const engine = entry.engine;
     const editButton =
         entry.shadowRoot!.querySelector<HTMLButtonElement>(`#editIconButton`)!;
-    assertTrue(!!editButton);
-    assertFalse(editButton.hidden);
+    assertTrue(isVisible(editButton));
 
     const promise =
         eventToPromise('view-or-edit-search-engine', entry).then(e => {
@@ -126,73 +151,51 @@ suite('SearchEngineEntryTest', function() {
     return promise;
   });
 
-  /**
-   * Checks that the given button is hidden for the given search engine.
-   */
-  function testButtonHidden(searchEngine: SearchEngine, buttonId: string) {
-    entry.engine = searchEngine;
-    const button =
-        entry.shadowRoot!.querySelector<HTMLButtonElement>(`#${buttonId}`);
-    assertTrue(!!button);
-    assertTrue(button.hidden);
-  }
-
   test('Remove_Hidden', function() {
-    testButtonHidden(createSampleSearchEngine({canBeRemoved: false}), 'delete');
+    assertButtonHidden(
+        entry, '#delete', createSampleSearchEngine({canBeRemoved: false}));
   });
 
   test('Activate_Hidden', function() {
-    flush();
-    testButtonHidden(
-        createSampleSearchEngine({canBeActivated: false}), 'activate');
+    assertButtonHidden(
+        entry, '#activate', createSampleSearchEngine({canBeActivated: false}));
   });
 
   test('Deactivate_Hidden', function() {
-    flush();
-    testButtonHidden(
-        createSampleSearchEngine({canBeDeactivated: false}), 'deactivate');
+    assertButtonHidden(
+        entry, '#deactivate',
+        createSampleSearchEngine({canBeDeactivated: false}));
   });
 
   test('Edit_Hidden', function() {
-    flush();
-    testButtonHidden(
-        createSampleSearchEngine({canBeActivated: true}), 'editIconButton');
+    assertButtonHidden(
+        entry, '#editIconButton',
+        createSampleSearchEngine({canBeActivated: true}));
 
-    flush();
-    testButtonHidden(
-        createSampleSearchEngine({isStarterPack: true}), 'editIconButton');
+    assertButtonHidden(
+        entry, '#editIconButton',
+        createSampleSearchEngine({isStarterPack: true}));
   });
-  /**
-   * Checks that the given button is disabled for the given search engine.
-   */
-  function testButtonDisabled(searchEngine: SearchEngine, buttonId: string) {
-    entry.engine = searchEngine;
-    const button =
-        entry.shadowRoot!.querySelector<HTMLButtonElement>(`#${buttonId}`);
-    assertTrue(!!button);
-    assertTrue(button.disabled);
-  }
 
   test('MakeDefault_Disabled', function() {
-    testButtonDisabled(
-        createSampleSearchEngine({canBeDefault: false}), 'makeDefault');
+    assertTrue(isButtonDisabled(
+        entry, '#makeDefault',
+        createSampleSearchEngine({canBeDefault: false})));
   });
 
   test('Edit_Disabled', function() {
-    flush();
-    testButtonDisabled(
-        createSampleSearchEngine({canBeEdited: false}), 'editIconButton');
+    assertTrue(isButtonDisabled(
+        entry, '#editIconButton',
+        createSampleSearchEngine({canBeEdited: false})));
   });
 
   // Test that clicking the "activate" button fires an activate event.
   test('Activate', async function() {
-    flush();
     entry.engine = createSampleSearchEngine({canBeActivated: true});
 
     const activateButton = entry.shadowRoot!.querySelector<HTMLButtonElement>(
         'cr-button.secondary-button')!;
-    assertTrue(!!activateButton);
-    assertFalse(activateButton.hidden);
+    assertTrue(isVisible(activateButton));
     activateButton.click();
 
     // Ensure that the activate event is fired.
@@ -204,7 +207,6 @@ suite('SearchEngineEntryTest', function() {
 
   // Test that clicking the "Deactivate" button fires a deactivate event.
   test('Deactivate', async function() {
-    flush();
     entry.engine = createSampleSearchEngine({canBeDeactivated: true});
 
     // Open action menu.
@@ -215,8 +217,7 @@ suite('SearchEngineEntryTest', function() {
 
     const deactivateButton = entry.shadowRoot!.querySelector<HTMLButtonElement>(
         'button#deactivate.dropdown-item')!;
-    assertTrue(!!deactivateButton);
-    assertFalse(deactivateButton.hidden);
+    assertTrue(isVisible(deactivateButton));
     deactivateButton.click();
 
     // Ensure that the deactivate event is fired.
@@ -229,7 +230,6 @@ suite('SearchEngineEntryTest', function() {
   // Test that the accessibility Aria labels are set correctly for the Edit,
   // Activate, and More Actions buttons.
   test('AriaLabelSetCorrectly', function() {
-    flush();
     entry.engine = createSampleSearchEngine(
         {default: false, canBeActivated: true, canBeEdited: true});
 
@@ -343,9 +343,9 @@ suite('OmniboxExtensionEntryTest', function() {
   let browserProxy: TestExtensionControlBrowserProxy;
 
   setup(function() {
+    document.body.innerHTML = window.trustedTypes!.emptyHTML;
     browserProxy = new TestExtensionControlBrowserProxy();
     ExtensionControlBrowserProxyImpl.setInstance(browserProxy);
-    document.body.innerHTML = window.trustedTypes!.emptyHTML;
     entry = document.createElement('settings-omnibox-extension-entry');
     entry.engine = createSampleOmniboxExtension();
     document.body.appendChild(entry);
@@ -375,88 +375,263 @@ suite('EnterpriseSiteSearchEntryTests', function() {
   let entry: SettingsSearchEngineEntryElement;
   let browserProxy: TestSearchEnginesBrowserProxy;
 
-  const searchEngine = createSampleSearchEngine({
-    id: 1,
-    name: 'managed',
-    canBeEdited: false,
-    displayName: 'Managed',
-    isManaged: true,
-  });
+  /**
+   * Creates a sample managed search engine.
+   */
+  const createSampleManagedSearchEngine = (): SearchEngine => {
+    return createSampleSearchEngine({
+      id: 1,
+      name: 'managed',
+      canBeEdited: false,
+      displayName: 'Managed',
+      isManaged: true,
+    });
+  };
+
+  /**
+   * Creates a sample overridable search engine.
+   */
+  const createSampleOverridableSearchEngine =
+      (isFeatured: boolean): SearchEngine => {
+        return createSampleSearchEngine({
+          id: 1,
+          name: 'recommended',
+          canBeEdited: !isFeatured,
+          canBeRemoved: !isFeatured,
+          canBeDeactivated: true,
+          displayName: 'Recommended',
+          isManaged: true,
+          shouldConfirmDeletion: true,
+        });
+      };
 
   setup(function() {
+    document.body.innerHTML = window.trustedTypes!.emptyHTML;
     browserProxy = new TestSearchEnginesBrowserProxy();
     SearchEnginesBrowserProxyImpl.setInstance(browserProxy);
-    document.body.innerHTML = window.trustedTypes!.emptyHTML;
     entry = document.createElement('settings-search-engine-entry');
-    entry.engine = searchEngine;
     document.body.appendChild(entry);
   });
 
   // Test that the <search-engine-entry> is populated according to its
   // underlying SearchEngine model.
   test('Initialization', function() {
-    flush();
-    assertEquals(
-        searchEngine.displayName,
-        entry.shadowRoot!.querySelector('#name-column')!.textContent!.trim());
-    assertEquals(
-        searchEngine.keyword,
-        entry.shadowRoot!.querySelector('#shortcut-column')!.textContent);
-    assertEquals(
-        searchEngine.url,
-        entry.shadowRoot!.querySelector('#url-column')!.textContent);
+    const assertSiteSearchInitialization =
+        (entry: SettingsSearchEngineEntryElement,
+         searchEngine: SearchEngine) => {
+          assertEquals(
+              searchEngine.displayName,
+              entry.shadowRoot!.querySelector(
+                                   '#name-column')!.textContent!.trim());
+          assertEquals(
+              searchEngine.keyword,
+              entry.shadowRoot!.querySelector('#shortcut-column')!.textContent);
+          assertEquals(
+              searchEngine.url,
+              entry.shadowRoot!.querySelector('#url-column')!.textContent);
+        };
+
+    // Test for managed engine.
+    const managedEngine = createSampleManagedSearchEngine();
+    entry.engine = managedEngine;
+    assertSiteSearchInitialization(entry, managedEngine);
+
+    // Test for overridable engine (featured).
+    const featuredOverridableEngine =
+        createSampleOverridableSearchEngine(/*isFeatured=*/ true);
+    entry.engine = featuredOverridableEngine;
+    assertSiteSearchInitialization(entry, featuredOverridableEngine);
+
+    // Test for overridable engine (unfeatured).
+    const unfeaturedOverridableEngine =
+        createSampleOverridableSearchEngine(/*isFeatured=*/ false);
+    entry.engine = unfeaturedOverridableEngine;
+    assertSiteSearchInitialization(entry, unfeaturedOverridableEngine);
   });
 
-  // Verifies that the "edit" and "activate" buttons and the 3-dot action menu
-  // are hidden.
-  test('BasicControlsHidden', function() {
-    flush();
+  // Verifies that the "Activate" button is hidden for all managed engines.
+  test('ActivateButtonBehavior', function() {
+    entry.engine = createSampleManagedSearchEngine();
+    assertButtonHidden(entry, '#activate');
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ true);
+    assertButtonHidden(entry, '#activate');
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ false);
+    assertButtonHidden(entry, '#activate');
+  });
 
+  // Verifies the visibility and functionality of the "edit" button for managed
+  // (hidden) and overridable (featured: hidden; unfeatured: visible and fires
+  // event) engines.
+  test('EditButtonBehavior', async function() {
+    // Test for managed engine (Edit button should be hidden).
+    entry.engine = createSampleManagedSearchEngine();
+    assertButtonHidden(entry, '#editIconButton');
+
+    // Test for featured overridable engine (Edit button should be hidden).
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ true);
+    assertButtonHidden(entry, '#editIconButton');
+
+    // Test for unfeatured overridable engine (Edit button should be visible and
+    // functional).
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ false);
+    const engineUnfeatured = entry.engine;
     const editButton =
-        entry.shadowRoot!.querySelector<HTMLButtonElement>(`#editIconButton`);
-    assertTrue(!!editButton);
-    assertTrue(editButton.hidden);
+        entry.shadowRoot!.querySelector<HTMLButtonElement>(`#editIconButton`)!;
+    assertTrue(isVisible(editButton));
 
-    const activateButton =
-        entry.shadowRoot!.querySelector<HTMLButtonElement>(`#activate`);
-    assertTrue(!!activateButton);
-    assertTrue(activateButton.hidden);
+    const whenFired = eventToPromise('view-or-edit-search-engine', entry);
+    editButton.click();
+    const e = await whenFired;
+    assertEquals(engineUnfeatured, e.detail.engine);
+    assertEquals(editButton, e.detail.anchorElement);
+  });
 
+  // Verifies that the action menu (three-dot menu) is visible. Non-overridable
+  // managed engines should have the menu disabled.
+  test('ActionMenuBehavior', function() {
+    // Test for managed engine (Menu should be visible and disabled).
+    entry.engine = createSampleManagedSearchEngine();
     const menuButton = entry.shadowRoot!.querySelector<HTMLElement>(
         'cr-icon-button.icon-more-vert');
-    assertTrue(!!menuButton);
-    assertTrue(menuButton.hidden);
+    assertTrue(isVisible(menuButton));
+    assertTrue(isButtonDisabled(entry, 'cr-icon-button.icon-more-vert'));
+
+    // Test for featured overridable engine (Action menu should be visible and
+    // not disabled).
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ true);
+    const menuButtonFeatured = entry.shadowRoot!.querySelector<HTMLElement>(
+        'cr-icon-button.icon-more-vert');
+    assertTrue(isVisible(menuButtonFeatured));
+    assertFalse(isButtonDisabled(entry, 'cr-icon-button.icon-more-vert'));
+
+    // Test for unfeatured overridable engine (Action menu should be visible and
+    // not disabled).
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ false);
+    const menuButtonUnfeatured = entry.shadowRoot!.querySelector<HTMLElement>(
+        'cr-icon-button.icon-more-vert');
+    assertTrue(isVisible(menuButtonUnfeatured));
+    assertFalse(isButtonDisabled(entry, 'cr-icon-button.icon-more-vert'));
   });
 
-  // Verifies that the details can be seen.
-  test('ViewDetailsAllowed', function() {
-    flush();
-
-    const engine = entry.engine;
-    const viewDetailsButton =
-        entry.shadowRoot!.querySelector<HTMLButtonElement>(
-            `#viewDetailsButton`);
-    assertTrue(!!viewDetailsButton);
-    assertFalse(viewDetailsButton.hidden);
-
-    const promise =
-        eventToPromise('view-or-edit-search-engine', entry).then(e => {
-          assertEquals(engine, e.detail.engine);
-          assertEquals(
-              entry.shadowRoot!.querySelector('cr-icon-button'),
-              e.detail.anchorElement);
-        });
-    viewDetailsButton.click();
-    return promise;
+  // Verifies that the "Make Default" button is disabled for all overridable
+  // engines.
+  test('MakeDefaultDisabled_Overridable', function() {
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ true);
+    assertTrue(isButtonDisabled(entry, '#makeDefault'));
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ false);
+    assertTrue(isButtonDisabled(entry, '#makeDefault'));
   });
 
-  // Verifies that the policy indicator is shown.
-  test('PolicyIndicator_Shown', function() {
-    flush();
+  // Verifies that clicking the "Deactivate" button in the action menu fires a
+  // deactivate event for both featured and unfeatured overridable engines.
+  test('DeactivateAllowed_Overridable', async function() {
+    const testDeactivation = async (isFeatured: boolean) => {
+      entry.engine = createSampleOverridableSearchEngine(isFeatured);
+      const menu = openActionMenu(entry);
 
-    const policyIndicator =
-        entry.shadowRoot!.querySelector('cr-policy-indicator');
-    assertTrue(!!policyIndicator);
-    assertFalse(policyIndicator.hidden);
+      const deactivateButton =
+          entry.shadowRoot!.querySelector<HTMLButtonElement>(
+              'button#deactivate.dropdown-item')!;
+      assertTrue(isVisible(deactivateButton));
+      deactivateButton.click();
+
+      const [modelIndex, isActive] =
+          await browserProxy.whenCalled('setIsActiveSearchEngine');
+      assertFalse(menu.open);
+      assertEquals(entry.engine.modelIndex, modelIndex);
+      assertFalse(isActive);
+    };
+
+    await testDeactivation(true);
+    await testDeactivation(false);
+  });
+
+  // Verifies the visibility and functionality of the "Remove" button for both
+  // featured (hidden) and unfeatured (visible and fires event for confirmation
+  // dialog) overridable engines.
+  test('RemoveButtonBehavior_Overridable', async function() {
+    // Test for featured engine (Remove button should be hidden).
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ true);
+    openActionMenu(entry);
+    assertButtonHidden(entry, 'button#delete.dropdown-item');
+
+    // Test for unfeatured engine (Remove button should be visible and
+    // functional).
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ false);
+    openActionMenu(entry);
+
+    const deleteButton = entry.shadowRoot!.querySelector<HTMLButtonElement>(
+        'button#delete.dropdown-item')!;
+    assertTrue(isVisible(deleteButton));
+
+    const whenFired = eventToPromise('delete-search-engine', entry);
+    deleteButton.click();
+    const e = await whenFired;
+    assertEquals(entry.engine, e.detail.engine);
+    assertEquals(
+        entry.shadowRoot!.querySelector('cr-icon-button.icon-more-vert'),
+        e.detail.anchorElement);
+  });
+
+  // Verifies the visibility and functionality of the "View Details" button for
+  // managed (visible and fires event) and overridable (featured: visible and
+  // fires event; unfeatured: hidden) engines.
+  test('ViewDetailsBehavior', async function() {
+    const testViewDetails =
+        async (engine: SearchEngine, shouldBeVisible: boolean) => {
+      entry.engine = engine;
+      if (shouldBeVisible) {
+        const managedEngine = entry.engine;
+        const viewDetailsButton =
+            entry.shadowRoot!.querySelector<HTMLButtonElement>(
+                `#viewDetailsButton`)!;
+        assertTrue(isVisible(viewDetailsButton));
+
+        const whenFired = eventToPromise('view-or-edit-search-engine', entry);
+        viewDetailsButton.click();
+        const e = await whenFired;
+        assertEquals(managedEngine, e.detail.engine);
+        assertEquals(
+            entry.shadowRoot!.querySelector('cr-icon-button'),
+            e.detail.anchorElement);
+      } else {
+        assertButtonHidden(entry, '#viewDetailsButton');
+      }
+    };
+
+    // Test for managed engine ("Details" button should be visible and
+    // functional).
+    await testViewDetails(
+        createSampleManagedSearchEngine(), /*shouldBeVisible=*/ true);
+
+    // Test for unfeatured overridable engine ("Details" button should be
+    // hidden).
+    await testViewDetails(
+        createSampleOverridableSearchEngine(/*isFeatured=*/ false),
+        /*shouldBeVisible=*/ false);
+
+    // Test for featured overridable engine ("Details" button should be visible
+    // and functional).
+    await testViewDetails(
+        createSampleOverridableSearchEngine(/*isFeatured=*/ true),
+        /*shouldBeVisible=*/ true);
+  });
+
+  // Verifies that the policy indicator is shown for all managed engines.
+  test('PolicyIndicatorShown', function() {
+    const assertSiteSearchPolicyIndicatorShown =
+        (entry: SettingsSearchEngineEntryElement) => {
+          flush();
+          const policyIndicator =
+              entry.shadowRoot!.querySelector('cr-policy-indicator');
+          assertTrue(isVisible(policyIndicator));
+        };
+
+    entry.engine = createSampleManagedSearchEngine();
+    assertSiteSearchPolicyIndicatorShown(entry);
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ true);
+    assertSiteSearchPolicyIndicatorShown(entry);
+    entry.engine = createSampleOverridableSearchEngine(/*isFeatured=*/ false);
+    assertSiteSearchPolicyIndicatorShown(entry);
   });
 });
