@@ -947,4 +947,151 @@ suite('General', () => {
       assertFalse(isHidden(labels));
     });
   });
+
+  suite('KeyboardNavigation', function() {
+    setup(() => {
+      loadTimeData.overrideValues({
+        bookmarksTreeViewEnabled: true,
+      });
+    });
+
+    test('expands and collapses folders with arrow keys', async () => {
+      // Re-initialize with tree view enabled.
+      powerBookmarksList = await initializeUi(bookmarksApi);
+
+      const folderRow = getPowerBookmarksRowElement(powerBookmarksList, '5');
+      assertTrue(!!folderRow);
+      assertFalse(
+          folderRow.toggleExpand, 'Folder should be initially collapsed');
+
+      // Child should not be visible initially.
+      assertFalse(
+          !!getPowerBookmarksRowElement(powerBookmarksList, '6'),
+          'Child bookmark should not be visible initially');
+
+      // Focus the item before sending key presses.
+      const urlListItem =
+          folderRow.shadowRoot.querySelector('cr-url-list-item')!;
+      urlListItem.focus();
+
+      // Expand with Right Arrow.
+      let toggleEvent =
+          eventToPromise('power-bookmark-toggle', powerBookmarksList);
+      folderRow.dispatchEvent(new KeyboardEvent(
+          'keydown', {key: 'ArrowRight', bubbles: true, composed: true}));
+      await toggleEvent;
+      await flushTasks();
+      await waitAfterNextRender(powerBookmarksList);
+      assertTrue(
+          folderRow.toggleExpand, 'Folder should be expanded after ArrowRight');
+      assertTrue(
+          !!getPowerBookmarksRowElement(powerBookmarksList, '6'),
+          'Child bookmark should be visible');
+
+      // Collapse with Left Arrow.
+      toggleEvent = eventToPromise('power-bookmark-toggle', powerBookmarksList);
+      folderRow.dispatchEvent(new KeyboardEvent(
+          'keydown', {key: 'ArrowLeft', bubbles: true, composed: true}));
+      await toggleEvent;
+      await flushTasks();
+      await waitAfterNextRender(powerBookmarksList);
+      assertFalse(
+          folderRow.toggleExpand, 'Folder should be collapsed after ArrowLeft');
+      assertFalse(
+          !!getPowerBookmarksRowElement(powerBookmarksList, '6'),
+          'Child bookmark should not be visible');
+    });
+
+    test(
+        'moves focus to first child on right arrow if already open',
+        async () => {
+          // Re-initialize with tree view enabled.
+          powerBookmarksList = await initializeUi(bookmarksApi);
+
+          const folderRow =
+              getPowerBookmarksRowElement(powerBookmarksList, '5');
+          assertTrue(!!folderRow);
+
+          // Expand the folder first.
+          const toggleEvent =
+              eventToPromise('power-bookmark-toggle', powerBookmarksList);
+          folderRow.dispatchEvent(
+              new MouseEvent('click', {bubbles: true, composed: true}));
+          await toggleEvent;
+          await flushTasks();
+          await waitAfterNextRender(powerBookmarksList);
+          assertTrue(folderRow.toggleExpand, 'Folder should be expanded');
+
+          const childRow = getPowerBookmarksRowElement(powerBookmarksList, '6');
+          assertTrue(!!childRow, 'Child bookmark should be visible');
+
+          // Focus the folder before sending key presses.
+          const urlListItem =
+              folderRow.shadowRoot.querySelector('cr-url-list-item')!;
+          urlListItem.focus();
+
+          // Right arrow on expanded folder should move focus.
+          folderRow.dispatchEvent(new KeyboardEvent(
+              'keydown', {key: 'ArrowRight', bubbles: true, composed: true}));
+          await flushTasks();
+
+          assertEquals(
+              childRow, powerBookmarksList.shadowRoot!.activeElement,
+              'Focus should move to the first child');
+        });
+
+    test('right arrow does nothing on non-folder', async () => {
+      const bookmarkRow = getPowerBookmarksRowElement(powerBookmarksList, '3');
+      assertTrue(!!bookmarkRow);
+
+      const urlListItem =
+          bookmarkRow.shadowRoot.querySelector('cr-url-list-item')!;
+      urlListItem.focus();
+
+      // This should not throw errors or change state.
+      bookmarkRow.dispatchEvent(new KeyboardEvent(
+          'keydown', {key: 'ArrowRight', bubbles: true, composed: true}));
+      await flushTasks();
+
+      // No toggleExpand property to check, just make sure nothing broke.
+      assertTrue(!!getPowerBookmarksRowElement(powerBookmarksList, '3'));
+    });
+
+    test('moves focus to parent on left arrow from child', async () => {
+      // Re-initialize with tree view enabled.
+      powerBookmarksList = await initializeUi(bookmarksApi);
+
+      const folderRow = getPowerBookmarksRowElement(powerBookmarksList, '5');
+      assertTrue(!!folderRow);
+
+      // Expand the folder first.
+      const toggleEvent =
+          eventToPromise('power-bookmark-toggle', powerBookmarksList);
+      folderRow.dispatchEvent(
+          new MouseEvent('click', {bubbles: true, composed: true}));
+      await toggleEvent;
+      await flushTasks();
+      await waitAfterNextRender(powerBookmarksList);
+      assertTrue(folderRow.toggleExpand, 'Folder should be expanded');
+
+      const childRow = getPowerBookmarksRowElement(powerBookmarksList, '6');
+      assertTrue(!!childRow, 'Child bookmark should be visible');
+
+      // Focus the child before sending key presses.
+      const childUrlListItem =
+          childRow.shadowRoot.querySelector('cr-url-list-item')!;
+      childUrlListItem.focus();
+
+      // Left arrow on child should move focus to parent and collapse it.
+      childRow.dispatchEvent(new KeyboardEvent(
+          'keydown', {key: 'ArrowLeft', bubbles: true, composed: true}));
+      await flushTasks();
+      await waitAfterNextRender(powerBookmarksList);
+
+      assertEquals(
+          folderRow, powerBookmarksList.shadowRoot!.activeElement,
+          'Focus should move to the parent folder');
+      assertFalse(folderRow.toggleExpand, 'Parent folder should be collapsed');
+    });
+  });
 });
