@@ -3,9 +3,10 @@
 // found in the LICENSE file.
 import 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 
-import {BrowserProxy, NodeStore, previousReadHighlightClass, ReadAloudHighlighter, ReadAloudNode, setInstance, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import {BrowserProxy, NodeStore, previousReadHighlightClass, ReadAloudHighlighter, ReadAloudNode, setInstance, VoiceLanguageController, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 import {assertEquals, assertFalse, assertStringContains, assertStringExcludes, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
 
+import {createSpeechSynthesisVoice} from './common.js';
 import {FakeReadingMode} from './fake_reading_mode.js';
 import {TestColorUpdaterBrowserProxy} from './test_color_updater_browser_proxy.js';
 import {TestReadAloudModelBrowserProxy} from './test_read_aloud_browser_proxy.js';
@@ -14,6 +15,7 @@ suite('Highlighter', () => {
   let highlighter: ReadAloudHighlighter;
   let nodeStore: NodeStore;
   let wordBoundaries: WordBoundaries;
+  let voiceLanguageController: VoiceLanguageController;
   let readAloudModel: TestReadAloudModelBrowserProxy;
 
   function assertFullNodeIsHighlighted(id: number, text: string) {
@@ -49,11 +51,13 @@ suite('Highlighter', () => {
 
     readAloudModel = new TestReadAloudModelBrowserProxy();
     setInstance(readAloudModel);
+    wordBoundaries = new WordBoundaries();
+    WordBoundaries.setInstance(wordBoundaries);
+    voiceLanguageController = new VoiceLanguageController();
+    VoiceLanguageController.setInstance(voiceLanguageController);
     highlighter = new ReadAloudHighlighter();
     nodeStore = NodeStore.getInstance();
     nodeStore.clear();
-    wordBoundaries = WordBoundaries.getInstance();
-    wordBoundaries.resetToDefaultState();
   });
 
   test('sentence highlight', () => {
@@ -164,6 +168,95 @@ suite('Highlighter', () => {
         id);
   });
 
+  test('word highlight with no boundaries uses sentence highlight', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.wordHighlighting);
+    const id = 10;
+    const text = 'Welcome to the house. ';
+    const sentence = document.createElement('p');
+    sentence.appendChild(document.createTextNode(text));
+    nodeStore.setDomNode(sentence, id);
+    const word = [{node: ReadAloudNode.create(sentence)!, start: 5, length: 5}];
+    readAloudModel.setHighlightForCurrentSegmentIndex(word);
+    const segments = [{
+      node: ReadAloudNode.create(sentence)!,
+      start: 0,
+      length: text.length,
+    }];
+    readAloudModel.setCurrentTextSegments(segments);
+
+    highlighter.highlightCurrentGranularity(
+        segments,
+        /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+
+    assertTrue(highlighter.hasCurrentGranularity());
+    assertHtml('<span class="current-read-highlight">' + text + '</span>', id);
+  });
+
+  test('word highlight with eSpeak voice uses sentence highlight', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.wordHighlighting);
+    const selectedVoice =
+        createSpeechSynthesisVoice({lang: 'en', name: 'Kristi eSpeak'});
+    voiceLanguageController.setUserPreferredVoice(selectedVoice);
+    const id = 10;
+    const text = 'To the Haus of Holbein. ';
+    const sentence = document.createElement('p');
+    sentence.appendChild(document.createTextNode(text));
+    nodeStore.setDomNode(sentence, id);
+    const word = [{node: ReadAloudNode.create(sentence)!, start: 5, length: 5}];
+    readAloudModel.setHighlightForCurrentSegmentIndex(word);
+    const segments = [{
+      node: ReadAloudNode.create(sentence)!,
+      start: 0,
+      length: text.length,
+    }];
+    readAloudModel.setCurrentTextSegments(segments);
+
+    highlighter.highlightCurrentGranularity(
+        segments,
+        /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+
+    assertTrue(highlighter.hasCurrentGranularity());
+    assertHtml('<span class="current-read-highlight">' + text + '</span>', id);
+  });
+
+  test('word highlight with engine length', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.wordHighlighting);
+    const engineLength = 4;
+    const segmenterLength = 5;
+    wordBoundaries.updateBoundary(0, engineLength);
+    const id = 10;
+    const sentence = document.createElement('p');
+    sentence.appendChild(
+        document.createTextNode('Hans Holbein goes around the world'));
+    nodeStore.setDomNode(sentence, id);
+    const highlights = [
+      {
+        node: ReadAloudNode.create(sentence)!,
+        start: 0,
+        length: segmenterLength,
+      },
+    ];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
+
+    highlighter.highlightCurrentGranularity(
+        highlights,
+        /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+
+    assertTrue(highlighter.hasCurrentGranularity());
+    // If the segmenter length was used, the space after Hans would be in the
+    // current highlight.
+    assertHtml(
+        '<span class="current-read-highlight">Hans</span> Holbein goes around' +
+            ' the world',
+        id);
+  });
+
   test(
       'onWillMoveToNextGranularity with word highlighting highlights the rest' +
           ' of the sentence',
@@ -237,6 +330,39 @@ suite('Highlighter', () => {
     assertHtml(' slipping into the lava.', id2);
   });
 
+  test('word highlight across multiple nodes without engine length', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.wordHighlighting);
+    wordBoundaries.updateBoundary(0);
+
+    const bold = document.createElement('b');
+    const text1 = 'April';
+    bold.appendChild(document.createTextNode(text1));
+    const sentence = document.createElement('p');
+    // A space is intentionally inserted into the beginning of this segment.
+    const text2 = ' 18, 2025';
+    sentence.appendChild(document.createTextNode(text2));
+    const id1 = 10;
+    const id2 = 12;
+    nodeStore.setDomNode(bold, id1);
+    nodeStore.setDomNode(sentence, id2);
+    const highlights = [
+      {node: ReadAloudNode.create(bold)!, start: 0, length: text1.length},
+      {node: ReadAloudNode.create(sentence)!, start: 0, length: 3},
+    ];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
+
+    highlighter.highlightCurrentGranularity(
+        highlights,
+        /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+
+    assertTrue(highlighter.hasCurrentGranularity());
+
+    assertHtml('<span class="current-read-highlight">April</span>', id1);
+    assertHtml('<span class="current-read-highlight"> 18</span>, 2025', id2);
+  });
+
   test('word highlight on punctuation only applies previous highlight', () => {
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.wordHighlighting);
@@ -271,6 +397,32 @@ suite('Highlighter', () => {
         id);
   });
 
+  test('word highlight with single alphabet character has highlight', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.wordHighlighting);
+    wordBoundaries.updateBoundary(0);
+    const id = 10;
+    const sentenceText = 'I know you will';
+    const sentence = document.createElement('p');
+    sentence.appendChild(document.createTextNode(sentenceText));
+    nodeStore.setDomNode(sentence, id);
+
+    const highlights = [{
+      node: ReadAloudNode.create(sentence)!,
+      start: 0,
+      length: 1,
+    }];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
+    highlighter.highlightCurrentGranularity(
+        highlights,
+        /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+
+    assertTrue(highlighter.hasCurrentGranularity());
+    assertHtml(
+        '<span class="current-read-highlight">I</span> know you will', id);
+  });
+
   test('phrase highlight', () => {
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.autoHighlighting);
@@ -297,6 +449,32 @@ suite('Highlighter', () => {
         id);
   });
 
+  test('phrase highlight with engine length, ignores engine length', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.autoHighlighting);
+    wordBoundaries.updateBoundary(0, 1);
+    const id = 10;
+    const sentence = document.createElement('p');
+    sentence.appendChild(document.createTextNode(
+        'But darling I will be loving you till we\'re 70.'));
+    nodeStore.setDomNode(sentence, id);
+    const highlights =
+        [{node: ReadAloudNode.create(sentence)!, start: 12, length: 20}];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
+
+    highlighter.highlightCurrentGranularity(
+        highlights,
+        /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+
+    assertTrue(highlighter.hasCurrentGranularity());
+    assertHtml(
+        '<span class="previous-read-highlight">But darling </span>' +
+            '<span class="current-read-highlight">I will be loving you' +
+            '</span> till we\'re 70.',
+        id);
+  });
+
   test(
       'onWillMoveToNextGranularity with phrase highlighting highlights the ' +
           'rest of the sentence',
@@ -401,6 +579,35 @@ suite('Highlighter', () => {
             id);
       });
 
+  test('with highlight off, sentence highlight used', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.noHighlighting);
+
+    const nodeId = 10;
+    const sentence = document.createElement('p');
+    const text1 = 'I\'ve been just one word. ';
+    const text2 = 'In a stupid rhyme. ';
+    sentence.appendChild(document.createTextNode(text1 + text2));
+    nodeStore.setDomNode(sentence, nodeId);
+    const segments = [{
+      node: ReadAloudNode.create(sentence)!,
+      start: text1.length,
+      length: text2.length,
+    }];
+    readAloudModel.setCurrentTextSegments(segments);
+
+    highlighter.highlightCurrentGranularity(
+        segments,
+        /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+
+    assertTrue(highlighter.hasCurrentGranularity());
+    assertHtml(
+        '<span class="previous-read-highlight">' + text1 + '</span>' +
+            '<span class="current-read-highlight">' + text2 + '</span>',
+        nodeId);
+  });
+
   test('clear highlights', () => {
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.sentenceHighlighting);
