@@ -46,32 +46,17 @@ class ReadAnythingMochaBrowserTest : public WebUIMochaBrowserTest {
 
 using ReadAnythingMochaTest = ReadAnythingMochaBrowserTest;
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, CheckmarkVisibleOnSelected) {
-  RunSidePanelTest(
-      "side_panel/read_anything/checkmark_visible_on_selected_test.js",
-      "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, Common) {
   RunSidePanelTest("side_panel/read_anything/common_test.js", "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, Images) {
-  RunSidePanelTest("side_panel/read_anything/image_test.js", "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, Logger) {
   RunSidePanelTest("side_panel/read_anything/read_anything_logger_test.js",
                    "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, LoadingScreen) {
-  RunSidePanelTest("side_panel/read_anything/loading_screen_test.js",
-                   "mocha.run()");
-}
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, EmptyState) {
-  RunSidePanelTest("side_panel/read_anything/empty_state_test.js",
+IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, AppContent) {
+  RunSidePanelTest("side_panel/read_anything/app_content_test.js",
                    "mocha.run()");
 }
 
@@ -97,11 +82,6 @@ IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, VoiceNotificationManager) {
       "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, ReadAloudFlag) {
-  RunSidePanelTest("side_panel/read_anything/read_aloud_flag_test.js",
-                   "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, FontSize) {
   RunSidePanelTest("side_panel/read_anything/font_size_test.js", "mocha.run()");
 }
@@ -133,11 +113,6 @@ IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, Toolbar) {
   RunSidePanelTest("side_panel/read_anything/toolbar_test.js", "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, UpdateContent) {
-  RunSidePanelTest("side_panel/read_anything/update_content_test.js",
-                   "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, AppReceivesToolbarChanges) {
   RunSidePanelTest(
       "side_panel/read_anything/app_receives_toolbar_changes_test.js",
@@ -159,86 +134,21 @@ IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, LanguageToast) {
                    "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, LinksToggle) {
-  RunSidePanelTest("side_panel/read_anything/links_toggle_button_test.js",
-                   "mocha.run()");
-}
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, ImagesToggle) {
-  RunSidePanelTest("side_panel/read_anything/images_toggle_button_test.js",
-                   "mocha.run()");
-}
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, PlayPause) {
-  RunSidePanelTest("side_panel/read_anything/play_pause_test.js",
-                   "mocha.run()");
-}
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, NextPrevious) {
-  RunSidePanelTest("side_panel/read_anything/next_previous_granularity_test.js",
-                   "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, RateMenu) {
   RunSidePanelTest("side_panel/read_anything/rate_menu_test.js", "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, FakeTreeBuilderTest) {
-  RunSidePanelTest("side_panel/read_anything/fake_tree_builder_test.js",
-                   "mocha.run()");
-}
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest,
-                       UpdateContentSelectionWithHighlights) {
-  RunSidePanelTest(
-      "side_panel/read_anything/"
-      "update_content_selection_with_highlights_test.js",
-      "mocha.run()");
-}
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, LanguageChanged) {
-  RunSidePanelTest("side_panel/read_anything/language_change_test.js",
-                   "mocha.run()");
-}
-
-#if BUILDFLAG(IS_CHROMEOS)
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, DownloadNotification) {
-  RunSidePanelTest("side_panel/read_anything/download_notification_test.js",
-                   "mocha.run()");
-}
-#endif
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, ToolbarOverflow) {
   RunSidePanelTest("side_panel/read_anything/toolbar_overflow_test.js",
                    "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, LinksToggledIntegration) {
-  RunSidePanelTest("side_panel/read_anything/links_toggled_integration_test.js",
-                   "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, SpeechUsesMaxTextLength) {
   RunSidePanelTest(
       "side_panel/read_anything/speech_uses_max_text_length_test.js",
       "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest,
-                       ReadAloud_UpdateContentSelection) {
-  RunSidePanelTest(
-      "side_panel/read_anything/read_aloud_update_content_selection_test.js",
-      "mocha.run()");
-}
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest,
-                       ReadAloud_UpdateContentSelectionPDF) {
-  RunSidePanelTest(
-      "side_panel/read_anything/"
-      "read_aloud_update_content_selection_pdf_test.js",
-      "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, ReadAloudHighlight) {
   RunSidePanelTest("side_panel/read_anything/read_aloud_highlighting_test.js",
                    "mocha.run()");
@@ -274,11 +184,6 @@ IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, UpdateContentIntegration) {
       "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, WordHighlighting) {
-  RunSidePanelTest("side_panel/read_anything/word_highlighting_test.js",
-                   "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, Highlighter) {
   RunSidePanelTest("side_panel/read_anything/highlighter_test.js",
                    "mocha.run()");
@@ -314,11 +219,6 @@ IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, SpeechModel) {
                    "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, ConnectedCallback) {
-  RunSidePanelTest("side_panel/read_anything/connected_callback_test.js",
-                   "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, HighlightMenu) {
   RunSidePanelTest("side_panel/read_anything/highlight_menu_test.js",
                    "mocha.run()");
@@ -329,32 +229,6 @@ IN_PROC_BROWSER_TEST_F(ReadAnythingMochaTest, TextSegmenter) {
                    "mocha.run()");
 }
 
-class ReadAnythingReadAloudPhraseHighlightingMochaTest
-    : public ReadAnythingMochaBrowserTest {
- protected:
-  ReadAnythingReadAloudPhraseHighlightingMochaTest() {
-    scoped_feature_list_.InitWithFeatures(
-        {features::kReadAnythingReadAloud,
-         features::kReadAnythingReadAloudPhraseHighlighting},
-        {});
-  }
-
- private:
-  base::test::ScopedFeatureList scoped_feature_list_;
-};
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingReadAloudPhraseHighlightingMochaTest,
-                       HighlightMenu) {
-  RunSidePanelTest("side_panel/read_anything/phrase_highlight_menu_test.js",
-                   "mocha.run()");
-}
-
-IN_PROC_BROWSER_TEST_F(ReadAnythingReadAloudPhraseHighlightingMochaTest,
-                       PhraseHighlighting) {
-  RunSidePanelTest("side_panel/read_anything/phrase_highlighting_test.js",
-                   "mocha.run()");
-}
-
 class ReadAnythingReadAloudTsSegmentationMochaTest
     : public ReadAnythingMochaBrowserTest {
  protected:
@@ -389,12 +263,6 @@ IN_PROC_BROWSER_TEST_F(ReadAnythingReadAloudTsSegmentationMochaTest,
                    "mocha.run()");
 }
 
-IN_PROC_BROWSER_TEST_F(ReadAnythingReadAloudTsSegmentationMochaTest,
-                       WordHighlighting) {
-  RunSidePanelTest("side_panel/read_anything/word_highlighting_test.js",
-                   "mocha.run()");
-}
-
 IN_PROC_BROWSER_TEST_F(ReadAnythingReadAloudTsSegmentationMochaTest,
                        DomReadAloudNode) {
   RunSidePanelTest("side_panel/read_anything/dom_read_aloud_node_test.js",
