@@ -1,13 +1,14 @@
 // Copyright 2025 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
-import {BrowserProxy, MAX_SPEECH_LENGTH, NodeStore, ReadAloudHighlighter, SpeechBrowserProxyImpl, SpeechController, VoiceLanguageController, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
-import {assertEquals, assertFalse, assertGT, assertNotEquals, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
+import {BrowserProxy, MAX_SPEECH_LENGTH, NodeStore, ReadAloudHighlighter, SelectionController, setInstance, SpeechBrowserProxyImpl, SpeechController, VoiceLanguageController, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import {assertEquals, assertFalse, assertGE, assertGT, assertNotEquals, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
 
-import {createSpeechErrorEvent, createSpeechSynthesisVoice, createWordBoundaryEvent, mockMetrics, setSimpleNodeStoreWithText, setSimpleTreeWithText} from './common.js';
+import {createSpeechErrorEvent, createSpeechSynthesisVoice, createWordBoundaryEvent, mockMetrics, setContent} from './common.js';
 import {FakeReadingMode} from './fake_reading_mode.js';
 import {TestColorUpdaterBrowserProxy} from './test_color_updater_browser_proxy.js';
 import type {TestMetricsBrowserProxy} from './test_metrics_browser_proxy.js';
+import {TestReadAloudModelBrowserProxy} from './test_read_aloud_browser_proxy.js';
 import {TestSpeechBrowserProxy} from './test_speech_browser_proxy.js';
 
 suite('SpeechController', () => {
@@ -23,13 +24,16 @@ suite('SpeechController', () => {
   let highlighter: ReadAloudHighlighter;
   let voiceLanguageController: VoiceLanguageController;
   let readingMode: FakeReadingMode;
+  let selectionController: SelectionController;
+  let readAloudModel: TestReadAloudModelBrowserProxy;
 
   // TODO: crbug.com/440400392- Move all tests relying on chrome.readingMode
   // for text segmentation to use TestReadAloudModelBrowserProxy instead.
   function onPlayPauseToggle(text: string) {
+    setContent(text, readAloudModel);
     const element = document.createElement('p');
     element.textContent = text;
-    speechController.onPlayPauseToggle(null, element);
+    speechController.onPlayPauseToggle(element);
   }
 
   setup(() => {
@@ -61,8 +65,15 @@ suite('SpeechController', () => {
       onPreviewVoicePlaying() {
         onPreviewVoicePlaying = true;
       },
+
+      onPlayingFromSelection() {
+
+      },
     };
 
+    readAloudModel = new TestReadAloudModelBrowserProxy();
+    setInstance(readAloudModel);
+    readAloudModel.setInitialized(true);
     voiceLanguageController = new VoiceLanguageController();
     voiceLanguageController.setUserPreferredVoice(
         createSpeechSynthesisVoice({lang: 'en', name: 'Google Alpaca'}));
@@ -73,6 +84,8 @@ suite('SpeechController', () => {
     WordBoundaries.setInstance(wordBoundaries);
     highlighter = new ReadAloudHighlighter();
     ReadAloudHighlighter.setInstance(highlighter);
+    selectionController = new SelectionController();
+    SelectionController.setInstance(selectionController);
     speechController = new SpeechController();
     speechController.addListener(speechListener);
     speech.reset();
@@ -147,7 +160,7 @@ suite('SpeechController', () => {
 
   test('onSpeechSettingsChange cancels and resumes speech if playing', () => {
     const text = 'In all the time I\'ve been by your side';
-    setSimpleTreeWithText(text);
+    setContent(text, readAloudModel);
     onPlayPauseToggle(text);
     speech.reset();
 
@@ -164,7 +177,7 @@ suite('SpeechController', () => {
 
   test('onSpeechSettingsChange does not resume speech if not playing', () => {
     speechController.setHasSpeechBeenTriggered(true);
-    setSimpleTreeWithText('I\'ve never lost control');
+    setContent('I\'ve never lost control', readAloudModel);
 
     speechController.onSpeechSettingsChange();
 
@@ -191,7 +204,7 @@ suite('SpeechController', () => {
 
   test('onPlayPauseToggle waits for engine load', async () => {
     const text = 'Sorry not sorry bout what I said';
-    setSimpleTreeWithText(text);
+    setContent(text, readAloudModel);
 
     onPlayPauseToggle(text);
     const spoken = await speech.whenCalled('speak');
@@ -215,7 +228,7 @@ suite('SpeechController', () => {
     const text = 'I\'m just tryna have some fun';
     chrome.readingMode.speechRate = rate;
     chrome.readingMode.baseLanguageForSpeech = lang;
-    setSimpleTreeWithText(text);
+    setContent(text, readAloudModel);
 
     onPlayPauseToggle(text);
 
@@ -226,6 +239,7 @@ suite('SpeechController', () => {
 
   test('onPlayPauseToggle pauses with button click', () => {
     onPlayPauseToggle('A story that you think');
+    speech.reset();
     onPlayPauseToggle('A story that you think');
 
     assertTrue(isSpeechActiveChanged);
@@ -258,7 +272,7 @@ suite('SpeechController', () => {
 
   test('word boundary received updates words heard', () => {
     const textContent = 'You\'re all I can think of';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     onPlayPauseToggle(textContent);
     const spoken = speech.getArgs('speak')[0];
 
@@ -270,7 +284,7 @@ suite('SpeechController', () => {
 
   test('words heard not updated for whitespace', () => {
     const textContent = 'Every drop I drink up';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     onPlayPauseToggle(textContent);
     const spoken = speech.getArgs('speak')[0];
 
@@ -282,7 +296,7 @@ suite('SpeechController', () => {
 
   test('words heard reset on clear', () => {
     const textContent = 'You\'re my soda pop';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     onPlayPauseToggle(textContent);
     const spoken = speech.getArgs('speak')[0];
 
@@ -297,7 +311,7 @@ suite('SpeechController', () => {
 
   test('sentence end with word boundaries, does not count sentence', () => {
     const textContent = 'My little soda pop';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     onPlayPauseToggle(textContent);
     const spoken = speech.getArgs('speak')[0];
 
@@ -310,7 +324,7 @@ suite('SpeechController', () => {
 
   test('sentence end with no word boundaries, counts sentence', () => {
     const textContent = 'Cool me down, you\'re so hot';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     onPlayPauseToggle(textContent);
     const spoken = speech.getArgs('speak')[0];
 
@@ -343,7 +357,7 @@ suite('SpeechController', () => {
         'here I stay- let the storm rage on';
 
     setup(() => {
-      setSimpleTreeWithText(longSentences);
+      setContent(longSentences, readAloudModel);
     });
 
     test('uses max speech length', () => {
@@ -355,7 +369,7 @@ suite('SpeechController', () => {
       assertGT(expectedNumSegments, 0);
       for (let i = 0; i < expectedNumSegments; i++) {
         assertEquals(i + 1, speech.getCallCount('speak'));
-        assertGT(
+        assertGE(
             MAX_SPEECH_LENGTH, speech.getArgs('speak')[i].text.trim().length);
         speech.getArgs('speak')[i].onend();
       }
@@ -387,7 +401,7 @@ suite('SpeechController', () => {
   test('stops speech on language-unavailable', async () => {
     const textContent = 'I\'m done cuz all this time';
     const pageLanguage = 'es';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     assertNotEquals(chrome.readingMode.defaultLanguageForSpeech, pageLanguage);
     chrome.readingMode.baseLanguageForSpeech = pageLanguage;
     voiceLanguageController.onPageLanguageChanged();
@@ -413,7 +427,7 @@ suite('SpeechController', () => {
   test('stops speech on voice-unavailable', async () => {
     const textContent = 'I\'ve been just one word';
     const pageLanguage = 'es';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     assertNotEquals(chrome.readingMode.defaultLanguageForSpeech, pageLanguage);
     chrome.readingMode.baseLanguageForSpeech = pageLanguage;
     voiceLanguageController.onPageLanguageChanged();
@@ -438,7 +452,7 @@ suite('SpeechController', () => {
   test('invalid argument updates speech rate', () => {
     const textContent = 'In a stupid rhyme';
     const pageLanguage = 'es';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     assertNotEquals(chrome.readingMode.defaultLanguageForSpeech, pageLanguage);
     chrome.readingMode.speechRate = 4;
     chrome.readingMode.baseLanguageForSpeech = pageLanguage;
@@ -463,7 +477,7 @@ suite('SpeechController', () => {
   test('speech interrupt while repositioning keeps playing speech', () => {
     const textContent = 'So I picked up a pen and a microphone';
     const pageLanguage = 'es';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     assertNotEquals(chrome.readingMode.defaultLanguageForSpeech, pageLanguage);
     chrome.readingMode.speechRate = 4;
     chrome.readingMode.baseLanguageForSpeech = pageLanguage;
@@ -490,7 +504,7 @@ suite('SpeechController', () => {
   test('speech interrupt stops speech', async () => {
     const textContent = 'History\'s about to get overthrown';
     const pageLanguage = 'es';
-    setSimpleTreeWithText(textContent);
+    setContent(textContent, readAloudModel);
     assertNotEquals(chrome.readingMode.defaultLanguageForSpeech, pageLanguage);
     chrome.readingMode.speechRate = 4;
     chrome.readingMode.baseLanguageForSpeech = pageLanguage;
@@ -521,11 +535,7 @@ suite('SpeechController', () => {
 
   test('speech finished clears state', async () => {
     const text = 'New phone who dis?';
-    setSimpleTreeWithText(text);
-    let resetGranularityIndex = false;
-    chrome.readingMode.resetGranularityIndex = () => {
-      resetGranularityIndex = true;
-    };
+    setContent(text, readAloudModel);
 
     onPlayPauseToggle(text);
 
@@ -534,11 +544,11 @@ suite('SpeechController', () => {
 
     speech.reset();
     isSpeechActiveChanged = false;
-    chrome.readingMode.getCurrentTextSegments = () => [];
+    readAloudModel.setCurrentTextSegments([]);
     spoken.onend();
 
     assertTrue(isSpeechActiveChanged);
-    assertTrue(resetGranularityIndex);
+    assertEquals(1, readAloudModel.getCallCount('resetSpeechToBeginning'));
     assertFalse(speechController.isSpeechActive());
     assertFalse(speechController.isPausedFromButton());
     assertFalse(speechController.isTemporaryPause());
@@ -549,43 +559,23 @@ suite('SpeechController', () => {
   });
 
   test('onNextGranularityClick propagates change', () => {
-    let movedToNext = false;
-    chrome.readingMode.getCurrentTextSegments = () => [];
-    chrome.readingMode.movePositionToNextGranularity = () => {
-      movedToNext = true;
-    };
-
     speechController.onNextGranularityClick();
-
-    assertTrue(movedToNext);
+    assertEquals(1, readAloudModel.getCallCount('moveSpeechForward'));
   });
 
   test('onPreviousGranularityClick propagates change', () => {
-    let movedToPrevious: boolean = false;
-    chrome.readingMode.getCurrentTextSegments = () => [];
-    chrome.readingMode.movePositionToPreviousGranularity = () => {
-      movedToPrevious = true;
-    };
-
     speechController.onPreviousGranularityClick();
-
-    assertTrue(movedToPrevious);
+    assertEquals(1, readAloudModel.getCallCount('moveSpeechBackwards'));
   });
 
-  test('onHighlightGranularityChange', async () => {
-    const granularity1 = chrome.readingMode.noHighlighting;
-    const granularity2 = chrome.readingMode.wordHighlighting;
+  test('onHighlightGranularityChange draws highlight', () => {
+    const granularity = chrome.readingMode.wordHighlighting;
+    setContent('no more melon cake', readAloudModel);
+    assertFalse(highlighter.hasCurrentGranularity());
 
-    speechController.onHighlightGranularityChange(granularity1);
-    assertEquals(granularity1, chrome.readingMode.highlightGranularity);
-    assertEquals(
-        granularity1, await metrics.whenCalled('recordHighlightGranularity'));
+    speechController.onHighlightGranularityChange(granularity);
 
-    metrics.reset();
-    speechController.onHighlightGranularityChange(granularity2);
-    assertEquals(granularity2, chrome.readingMode.highlightGranularity);
-    assertEquals(
-        granularity2, await metrics.whenCalled('recordHighlightGranularity'));
+    assertTrue(highlighter.hasCurrentGranularity());
   });
 
   test('onLockScreen while paused does nothing', () => {
@@ -607,29 +597,6 @@ suite('SpeechController', () => {
     assertEquals(0, speech.getCallCount('speak'));
   });
 
-  test('onVoiceMenuClose resume speech only if it was active before', () => {
-    const text = 'You must agree that baby';
-    setSimpleNodeStoreWithText(text);
-    speechController.onVoiceMenuOpen();
-
-    speechController.onVoiceMenuClose();
-
-    assertEquals(0, speech.getCallCount('cancel'));
-    assertEquals(0, speech.getCallCount('pause'));
-    assertEquals(0, speech.getCallCount('speak'));
-
-    onPlayPauseToggle(text);
-    speechController.onVoiceMenuOpen();
-    onPlayPauseToggle(text);
-    speech.reset();
-
-    speechController.onVoiceMenuClose();
-
-    assertEquals(1, speech.getCallCount('resume'));
-    assertEquals(0, speech.getCallCount('cancel'));
-    assertEquals(0, speech.getCallCount('speak'));
-  });
-
   test('onVoiceSelected sets current voice', () => {
     const voice1 = createSpeechSynthesisVoice({lang: 'pt-pt', name: 'Donkey'});
     const voice2 = createSpeechSynthesisVoice({lang: 'pt-br', name: 'Corgi'});
@@ -661,64 +628,4 @@ suite('SpeechController', () => {
     speechController.onVoiceSelected(voice3);
     assertFalse(wordBoundaries.hasBoundaries());
   });
-
-  test('set previous reading position without saved state does nothing', () => {
-    const text = 'But I took your hand';
-    setSimpleNodeStoreWithText(text);
-    wordBoundaries.updateBoundary(4);
-    speechController.onHighlightGranularityChange(
-        chrome.readingMode.sentenceHighlighting);
-    onPlayPauseToggle(text);
-    onPlayPauseToggle(text);
-    assertTrue(speechController.hasSpeechBeenTriggered());
-    assertTrue(wordBoundaries.hasBoundaries());
-    assertTrue(highlighter.hasCurrentGranularity());
-
-    speechController.clearReadAloudState();
-    speechController.setPreviousReadingPositionIfExists();
-
-    assertFalse(speechController.hasSpeechBeenTriggered());
-    assertFalse(wordBoundaries.hasBoundaries());
-    assertFalse(highlighter.hasCurrentGranularity());
-  });
-
-  test('set previous reading position restores saved state', () => {
-    const text = 'And promised I\'d withstand';
-    setSimpleNodeStoreWithText(text);
-    wordBoundaries.updateBoundary(4);
-    speechController.onHighlightGranularityChange(
-        chrome.readingMode.sentenceHighlighting);
-    onPlayPauseToggle(text);
-    onPlayPauseToggle(text);
-    assertTrue(speechController.hasSpeechBeenTriggered());
-    assertTrue(wordBoundaries.hasBoundaries());
-    assertTrue(highlighter.hasCurrentGranularity());
-
-    speechController.saveReadAloudState();
-    speechController.clearReadAloudState();
-    speechController.setPreviousReadingPositionIfExists();
-
-    assertTrue(speechController.hasSpeechBeenTriggered());
-    assertTrue(wordBoundaries.hasBoundaries());
-    assertTrue(highlighter.hasCurrentGranularity());
-  });
-
-  test('onTabMuteStateChange updates speech volume', async () => {
-    const text = 'We\'ll bring the cinches';
-    chrome.readingMode.isSpeechTreeInitialized = true;
-    setSimpleNodeStoreWithText(text);
-
-    speechController.onTabMuteStateChange(true);
-    onPlayPauseToggle(text);
-
-    let spoken = await speech.whenCalled('speak');
-    assertEquals(0, spoken.volume);
-
-    speech.reset();
-    speechController.onTabMuteStateChange(false);
-    onPlayPauseToggle(text);
-
-    spoken = await speech.whenCalled('speak');
-    assertEquals(1, spoken.volume);
-  });
 });
